@@ -3,7 +3,8 @@
 #' @import paradox
 #' @import mlr3misc
 #' @importFrom R6 R6Class
-#' @importFrom utils capture.output
+#' @importFrom utils capture.output head tail
+#' @importFrom methods formalArgs
 "_PACKAGE"
 
 .onLoad = function(libname, pkgname) {
@@ -14,3 +15,6 @@
     lg$set_threshold("warn")
   }
 } # nocov end
+
+
+leanify_package()
